@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 use Code::TidyAll::Config::INI::Reader 0.44;
 use List::Util 1.45 qw( uniqstr );
@@ -144,20 +144,12 @@ sub _tidyall_ini_content {
 sub _new_tidyall_ini {
     my $self = shift;
 
-    my $perl_select = '**/*.{pl,pm,t,psgi}';
+    my $perl_select = ['**/*.{pl,pm,t,psgi}'];
     my %tidyall     = (
-        'PerlTidy' => {
-            select => [$perl_select],
-            ignore => [ $self->_default_perl_ignore ],
-        },
-        'PerlCritic' => {
-            select => [$perl_select],
-            ignore => [ $self->_default_perl_ignore ],
-        },
-        'Test::Vars' => {
-            select => ['**/*.pm'],
-            ignore => [ $self->_default_perl_ignore ],
-        },
+        q{_}         => { ignore => $self->_default_perl_ignore },
+        'PerlTidy'   => { select => $perl_select },
+        'PerlCritic' => { select => $perl_select },
+        'Test::Vars' => { select => ['**/*.pm'] },
     );
 
     return $self->_config_to_ini( \%tidyall );
@@ -169,18 +161,6 @@ sub _munged_tidyall_ini {
     my $tidyall
         = Code::TidyAll::Config::INI::Reader->read_file('tidyall.ini');
 
-    my %has_default_ignore
-        = map { $_ => 1 } qw( PerlTidy PerlCritic Test::Vars );
-    for my $section ( grep { $has_default_ignore{$_} } sort keys %{$tidyall} )
-    {
-        $tidyall->{$section}{ignore} = [
-            uniqstr(
-                @{ $tidyall->{$section}{ignore} },
-                $self->_default_perl_ignore,
-            )
-        ];
-    }
-
     return $self->_config_to_ini($tidyall);
 }
 
@@ -200,7 +180,7 @@ sub _default_perl_ignore {
     my $dist = $self->zilla->name;
     push @ignore, "$dist-*/**/*";
 
-    return @ignore;
+    return \@ignore;
 }
 
 sub _config_to_ini {
@@ -233,8 +213,10 @@ sub _config_to_ini {
     );
 
     my $ini = q{};
-    for my $section ( sort keys %{$tidyall} ) {
-        $ini .= "[$section]\n";
+    for my $section ( q{_}, sort grep { $_ ne q{_} } keys %{$tidyall} ) {
+        if ( $section ne q{_} ) {
+            $ini .= "[$section]\n";
+        }
 
         for my $key ( $sorter->( keys %{ $tidyall->{$section} } ) ) {
             for my $val (
@@ -285,7 +267,7 @@ Dist::Zilla::Plugin::DROLSKY::TidyAll - Creates default tidyall.ini, perltidyrc,
 
 =head1 VERSION
 
-version 0.80
+version 0.81
 
 =for Pod::Coverage .*
 
