@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 use Dist::Zilla 6.0;
 
@@ -509,6 +509,7 @@ sub _explicit_prereq_plugins {
             'Prereqs' => 'Modules for use with tidyall' => {
                 -phase                              => 'develop',
                 -type                               => 'requires',
+                'Code::TidyAll'                     => '0.56',
                 'Code::TidyAll::Plugin::Test::Vars' => '0.02',
                 'Parallel::ForkManager'             => '1.19',
                 'Perl::Critic'                      => '1.126',
@@ -615,6 +616,7 @@ sub _all_stopwords {
         open my $fh, '<:encoding(UTF-8)', $self->stopwords_file;
         while (<$fh>) {
             chomp;
+            next unless length $_ && $_ !~ /^\#/;
             push @stopwords, $_;
         }
         close $fh;
@@ -797,7 +799,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.80
+version 0.81
 
 =head1 SYNOPSIS
 
